"use client";
"use client;";
import React__default, { useState, useRef, useEffect } from "react";
import { Div } from "../../Element/Tags.js";
import { InputField } from "../InputField/InputField.js";
import { Badge } from "../../Badge/Badge.js";
import { Text } from "../../Typography/Text.js";
import { BaseInputComponent } from "../BaseInputComponent/BaseInputComponent.js";
import { u as useClickOutside } from "../../../UseClickOutside-CJ5IQE6n.js";
import { searchOptions } from "./listBoxUtils.js";
const ListBox = React__default.forwardRef(
  ({
    options,
    label,
    placeholder = "Select an option",
    id,
    allowMultiSelect = false,
    onChange,
    disabled,
    badgeBgColour,
    badgeBgColor,
    badgeTextColour,
    badgeTextColor,
    selectionLimit,
    allowCustomEntries = false,
    ...props
  }, ref) => {
    const [isOpen, setIsOpen] = useState(false);
    const [selectedOption, setSelectedOption] = useState(null);
    const [selectedOptions, setSelectedOptions] = useState([]);
    const [searchValue, setSearchValue] = useState("");
    const [activeIndex, setActiveIndex] = useState(-1);
    const dropdownRef = useRef();
    const searchInputRef = useRef(null);
    const effectiveRef = ref || dropdownRef;
    const listboxId = id || `listbox-${Math.random().toString(36).substring(2, 9)}`;
    const filteredOptions = searchOptions(options, searchValue);
    const handleSelectOption = (option) => {
      if (option.disabled) return;
      let newSelectedOptions;
      if (allowMultiSelect) {
        const isSelected = selectedOptions.some((opt) => opt.value === option.value);
        if (isSelected) {
          newSelectedOptions = selectedOptions.filter((opt) => opt.value !== option.value);
        } else {
          if (selectionLimit && selectedOptions.length >= selectionLimit) {
            return;
          }
          newSelectedOptions = [...selectedOptions, option];
        }
        setSelectedOptions(newSelectedOptions);
        onChange == null ? void 0 : onChange(newSelectedOptions.map((opt) => opt.value));
        setSearchValue("");
        setActiveIndex(-1);
      } else {
        newSelectedOptions = [option];
        setSelectedOption(option);
        setSelectedOptions(newSelectedOptions);
        onChange == null ? void 0 : onChange(option.value);
        setIsOpen(false);
        setSearchValue("");
        setActiveIndex(-1);
      }
    };
    const handleDeleteOption = (e, valueToRemove) => {
      e.stopPropagation();
      const newSelectedOptions = selectedOptions.filter((opt) => opt.value !== valueToRemove);
      setSelectedOptions(newSelectedOptions);
      onChange == null ? void 0 : onChange(newSelectedOptions.map((opt) => opt.value));
    };
    const handleCustomEntry = () => {
      if (!searchValue.trim() || !allowCustomEntries) return;
      const customOption = {
        value: searchValue.trim(),
        label: searchValue.trim()
      };
      handleSelectOption(customOption);
      setSearchValue("");
      setActiveIndex(-1);
    };
    const handleClearAll = (e) => {
      e.stopPropagation();
      setSelectedOptions([]);
      onChange == null ? void 0 : onChange([]);
    };
    const handleKeyDown = (event) => {
      switch (event.key) {
        case "ArrowDown":
          event.preventDefault();
          if (!isOpen) {
            setIsOpen(true);
            setActiveIndex(0);
          } else {
            setActiveIndex(
              (prev) => prev < filteredOptions.length - 1 ? prev + 1 : prev
            );
          }
          break;
        case "ArrowUp":
          event.preventDefault();
          setActiveIndex((prev) => prev > 0 ? prev - 1 : prev);
          break;
        case "Enter":
          event.preventDefault();
          if (allowCustomEntries && searchValue.trim()) {
            const exactMatch = filteredOptions.find(
              (opt) => opt.label.toLowerCase() === searchValue.trim().toLowerCase()
            );
            if (exactMatch) {
              handleSelectOption(exactMatch);
            } else {
              handleCustomEntry();
            }
          } else if (activeIndex >= 0 && filteredOptions[activeIndex]) {
            handleSelectOption(filteredOptions[activeIndex]);
          }
          break;
        case "Escape":
          event.preventDefault();
          setIsOpen(false);
          setActiveIndex(-1);
          break;
        case " ":
          if (!isOpen) {
            event.preventDefault();
            setIsOpen(true);
            setActiveIndex(0);
          }
          break;
        case "Home":
          if (isOpen) {
            event.preventDefault();
            setActiveIndex(0);
          }
          break;
        case "End":
          if (isOpen) {
            event.preventDefault();
            setActiveIndex(filteredOptions.length - 1);
          }
          break;
      }
    };
    useClickOutside(effectiveRef, () => {
      setIsOpen(false);
      setActiveIndex(-1);
    });
    useEffect(() => {
      if (isOpen && searchInputRef.current) {
        searchInputRef.current.focus();
      }
    }, [isOpen]);
    useEffect(() => {
      if (activeIndex >= 0) {
        const activeOption = document.querySelector(`[data-index="${activeIndex}"]`);
        activeOption == null ? void 0 : activeOption.scrollIntoView({ block: "nearest" });
      }
    }, [activeIndex]);
    return /* @__PURE__ */ React__default.createElement(
      BaseInputComponent,
      {
        "data-list-box": true,
        className: `list-box-wrapper ${disabled ? "disabled" : ""}`,
        "aria-disabled": disabled,
        ref: effectiveRef,
        ...props
      },
      label && /* @__PURE__ */ React__default.createElement(
        "label",
        {
          id: `${listboxId}-label`,
          htmlFor: `${listboxId}-listbox`,
          className: "list-box-label"
        },
        label
      ),
      /* @__PURE__ */ React__default.createElement(
        Div,
        {
          className: "list-box-input-wrapper",
          onClick: () => !disabled && setIsOpen(!isOpen),
          onKeyDown: handleKeyDown,
          role: "combobox",
          "aria-haspopup": "listbox",
          "aria-expanded": isOpen,
          "aria-labelledby": `${listboxId}-label`,
          "aria-controls": `${listboxId}-listbox`,
          "aria-owns": `${listboxId}-listbox`,
          tabIndex: disabled ? -1 : 0
        },
        allowMultiSelect ? /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, selectedOptions.length > 0 ? /* @__PURE__ */ React__default.createElement(Div, { className: "options-wrapper" }, /* @__PURE__ */ React__default.createElement(Div, { className: "options-list" }, selectedOptions.map((option) => /* @__PURE__ */ React__default.createElement(
          Badge,
          {
            key: option.value,
            withDelete: allowMultiSelect,
            onDelete: (e) => handleDeleteOption(e, option.value),
            size: "small",
            shape: "rounded",
            bgColour: badgeBgColour || badgeBgColor,
            textColour: badgeTextColour || badgeTextColor
          },
          option.label
        ))), selectionLimit && selectedOptions.length >= selectionLimit && /* @__PURE__ */ React__default.createElement(
          Text,
          {
            className: "options-limit-warning",
            textColour: "red",
            size: "small",
            role: "alert"
          },
          "You can choose only ",
          selectionLimit,
          " option",
          selectionLimit === 1 ? "" : "s"
        )) : /* @__PURE__ */ React__default.createElement("span", { className: "placeholder" }, placeholder), selectedOptions.length > 0 && /* @__PURE__ */ React__default.createElement(
          Div,
          {
            className: "icon-wrapper clear-all",
            title: "Clear all options",
            onClick: handleClearAll,
            role: "button",
            tabIndex: 0,
            "aria-label": "Clear all selected options"
          },
          /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24", "aria-hidden": "true" }, /* @__PURE__ */ React__default.createElement("line", { x1: "5", y1: "5", x2: "19", y2: "19" }), /* @__PURE__ */ React__default.createElement("line", { x1: "5", y1: "19", x2: "19", y2: "5" }))
        )) : (
          // FOR PLAIN TEXT SINGLE-SELECT OPTION =========================================================
          selectedOption ? /* @__PURE__ */ React__default.createElement(Text, { className: "selected-option" }, selectedOption.label) : /* @__PURE__ */ React__default.createElement("span", { className: "placeholder" }, placeholder)
        ),
        /* @__PURE__ */ React__default.createElement(Div, { className: "icon-wrapper chevrons" }, /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24", "aria-hidden": "true" }, /* @__PURE__ */ React__default.createElement("polyline", { points: "6 9 12 4 18 9" }), /* @__PURE__ */ React__default.createElement("polyline", { points: "6 15 12 20 18 15" })))
      ),
      isOpen && !disabled && /* @__PURE__ */ React__default.createElement(
        Div,
        {
          className: "list-box-dropdown",
          role: "dialog",
          "aria-label": `${label || "Options"} dropdown`
        },
        /* @__PURE__ */ React__default.createElement(Div, { className: "list-box-search-wrapper" }, /* @__PURE__ */ React__default.createElement(
          InputField,
          {
            type: "text",
            ref: searchInputRef,
            className: "list-box-search",
            placeholder: "Search",
            value: searchValue,
            onChange: (e) => {
              setSearchValue(e.target.value);
            },
            onKeyDown: handleKeyDown,
            "aria-controls": `${listboxId}-listbox`,
            "aria-label": "Search options"
          }
        ), allowCustomEntries && searchValue.trim() && !selectedOptions.some((opt) => opt.label.toLowerCase() === searchValue.trim().toLowerCase()) && /* @__PURE__ */ React__default.createElement(
          "kbd",
          {
            className: "list-box-enter-key",
            "aria-label": "Press Enter to add custom option"
          },
          "↵"
        )),
        /* @__PURE__ */ React__default.createElement(
          "ul",
          {
            id: `${listboxId}-listbox`,
            className: "list-box-options",
            role: "listbox",
            "aria-label": label || "Select options",
            "aria-multiselectable": allowMultiSelect,
            "aria-busy": props.isLoading,
            tabIndex: -1
          },
          filteredOptions.length > 0 ? filteredOptions.map((option, index) => /* @__PURE__ */ React__default.createElement(
            "li",
            {
              key: option.value,
              id: `${listboxId}-option-${option.value}`,
              className: `list-box-option ${option.disabled ? "disabled" : ""} ${activeIndex === index ? "active" : ""}`,
              role: "option",
              "aria-selected": selectedOptions.some((opt) => opt.value === option.value),
              "aria-disabled": option.disabled,
              onClick: () => handleSelectOption(option),
              "data-index": index,
              tabIndex: -1
            },
            option.customLabel || option.label
          )) : /* @__PURE__ */ React__default.createElement(
            "li",
            {
              className: "list-box-option disabled",
              role: "alert",
              "aria-live": "polite"
            },
            "No matches found"
          )
        )
      )
    );
  }
);
export {
  ListBox
};
