"use client";
"use client;";
import React__default, { useRef, useState, useCallback, useEffect, createRef, useImperativeHandle } from "react";
import { InputField } from "../InputField/InputField.js";
import { Div } from "../../Element/Tags.js";
function validate(value, type) {
  const NUMERIC_REGEX = /^[0-9]+$/;
  const ALPHA_NUMERIC_REGEX = /^[a-zA-Z0-9]+$/i;
  const regex = type === "alphanumeric" ? ALPHA_NUMERIC_REGEX : NUMERIC_REGEX;
  return regex.test(value);
}
const PinInputField = React__default.forwardRef(
  ({
    numberOfFields: length,
    onChange,
    type = "number",
    mask = false,
    isOTP = false,
    autoFocus = false,
    pasteFromClipboard = "enabled",
    focusFirstInputOnReset = true,
    isFullWidth,
    ariaLabel,
    ...props
  }, ref) => {
    const pinInputFieldRef = useRef(null);
    const [inputRefs, setInputRefs] = useState([]);
    const [values, setValues] = useState([]);
    const [moveFocus, setMoveFocus] = useState(true);
    const [focusedIndex, setFocusedIndex] = useState(-1);
    const inputGroupId = props.id || `pin-input-${Math.random().toString(36).substring(2, 9)}`;
    const inputDescription = ariaLabel || "Enter verification code";
    const focus = useCallback(
      (index) => {
        var _a;
        const ref2 = inputRefs[index];
        (_a = ref2 == null ? void 0 : ref2.current) == null ? void 0 : _a.focus();
      },
      [inputRefs]
    );
    const focusNext = useCallback(
      (index) => {
        if (!moveFocus) return;
        const next = index + 1 < length ? index + 1 : null;
        if (next) {
          focus(next);
        }
      },
      [focus, length, moveFocus]
    );
    const handleResetPinInput = useCallback(() => {
      setValues(Array(length).fill(""));
      onChange == null ? void 0 : onChange("");
      if (focusFirstInputOnReset) {
        focus(0);
        setFocusedIndex(0);
      }
    }, [length, onChange, focus, focusFirstInputOnReset]);
    const setValue = useCallback(
      (value, index) => {
        const nextValues = [...values];
        nextValues[index] = value;
        setValues(nextValues);
        onChange == null ? void 0 : onChange(nextValues.join(""));
        const isComplete = value !== "" && nextValues.length === length && nextValues.every((inputValue) => inputValue != null && inputValue !== "") && index == length - 1;
        if (!isComplete) {
          setMoveFocus(true);
          focusNext(index);
        }
      },
      [focusNext, length, onChange, values]
    );
    const handleInputChange = (event, inputFieldIndex) => {
      const eventValue = event.currentTarget.value;
      const currentValue = values[inputFieldIndex];
      if (eventValue === "") {
        setValue("", inputFieldIndex);
        return;
      }
      if (eventValue.length > 1 && inputFieldIndex < length - 1) {
        if (validate(eventValue, type)) {
          let nextValue = [];
          if (currentValue == "") {
            nextValue = eventValue.split("").filter((_, j) => inputFieldIndex + j < length);
          } else if (event.currentTarget.selectionEnd === eventValue.length) {
            nextValue = eventValue.split("").filter((_, j) => j > 0 && inputFieldIndex + j - 1 < length);
          } else {
            nextValue = eventValue.split("").filter((_, j) => j < eventValue.length - 1 && inputFieldIndex + j < length);
          }
          setValues(
            (values2) => values2.map(
              (v, j) => j >= inputFieldIndex && j < inputFieldIndex + nextValue.length ? nextValue[j - inputFieldIndex] : v
            )
          );
          focus(
            inputFieldIndex + nextValue.length < length ? inputFieldIndex + nextValue.length : length - 1
          );
          onChange == null ? void 0 : onChange(nextValue.join(""));
        }
      } else {
        let nextValue = eventValue;
        if ((currentValue == null ? void 0 : currentValue.length) > 0) {
          if (currentValue[0] === eventValue.charAt(0)) {
            nextValue = eventValue.charAt(1);
          } else if (currentValue[0] === eventValue.charAt(1)) {
            nextValue = eventValue.charAt(0);
          }
        }
        if (validate(nextValue, type)) {
          setValue(nextValue, inputFieldIndex);
        }
      }
    };
    const onKeyDown = (event, i) => {
      var _a;
      if (event.key === "Backspace") {
        if (event.target.value === "") {
          if (i > 0) {
            const newIndex = i - 1;
            setValue("", newIndex);
            focus(newIndex);
            setMoveFocus(true);
          }
        } else {
          setMoveFocus(false);
        }
      } else if (event.key === "Escape") {
        (_a = inputRefs[i].current) == null ? void 0 : _a.blur();
        onBlur();
      } else if (event.key === "ArrowRight") {
        if (i < length - 1) {
          focus(i + 1);
        }
      } else if (event.key === "ArrowLeft") {
        if (i > 0) {
          focus(i - 1);
        }
      }
    };
    const onFocus = (e, i) => {
      setFocusedIndex(i);
    };
    const onSelect = (e) => {
      const target = e.target;
      setTimeout(() => {
        target.setSelectionRange(target.value.length, target.value.length);
      }, 0);
    };
    const onBlur = () => {
      setFocusedIndex(-1);
    };
    useEffect(() => {
      setInputRefs((inputRefs2) => {
        const refs = Array(length).fill(0).map((_, i) => {
          var _a;
          const ref2 = inputRefs2[i] || createRef();
          if (autoFocus && i === 0) {
            (_a = ref2.current) == null ? void 0 : _a.focus();
          }
          return ref2;
        });
        return refs;
      });
    }, [length, autoFocus]);
    useImperativeHandle(
      ref,
      () => ({
        ...pinInputFieldRef.current,
        reset: handleResetPinInput
      }),
      [handleResetPinInput]
    );
    let classNames = [];
    if (isFullWidth) {
      classNames.push("full-width");
    }
    return /* @__PURE__ */ React__default.createElement(
      Div,
      {
        "data-pin-input-field": true,
        ref: pinInputFieldRef,
        classNames,
        role: "group",
        "aria-label": inputDescription,
        "aria-required": props.required,
        ...props
      },
      [...Array(length)].map((_, i) => /* @__PURE__ */ React__default.createElement(
        InputField,
        {
          key: i,
          id: `${inputGroupId}-${i}`,
          ref: inputRefs[i],
          type: mask ? "password" : type === "number" ? "tel" : "text",
          inputMode: type === "number" ? "numeric" : "text",
          onChange: (e) => handleInputChange(e, i),
          onKeyDown: (e) => onKeyDown(e, i),
          onFocus: (e) => onFocus(e, i),
          onSelect: (e) => onSelect(e),
          onBlur,
          placeholder: focusedIndex !== i ? `⦁` : void 0,
          autoComplete: isOTP ? "one-time-code" : "off",
          value: values[i] || "",
          autoFocus: autoFocus && i === 0,
          onCopy: (e) => pasteFromClipboard === "disabled" && e.preventDefault(),
          onPaste: (e) => pasteFromClipboard === "disabled" && e.preventDefault(),
          "aria-label": `Digit ${i + 1} of ${length}`,
          "aria-required": props.required
        }
      ))
    );
  }
);
export {
  PinInputField
};
