"use client";
"use client;";
import React__default, { useEffect } from "react";
import { Element } from "../Element/Element.js";
import { Text } from "../Typography/Text.js";
const Modal = React__default.forwardRef(
  ({
    id,
    children,
    classNames = [],
    isDismissible = true,
    showBackdrop,
    blurBackdrop,
    label,
    description,
    ...props
  }, ref) => {
    const modalId = `${id}`;
    const descriptionId = description ? `${modalId}-description` : void 0;
    if (showBackdrop) {
      classNames.push("show-backdrop");
    }
    if (blurBackdrop) {
      classNames.push("blur-backdrop");
    }
    useEffect(() => {
      const handleEscape = (e) => {
        if (e.key === "Escape" && isDismissible) {
          hideModal(id);
        }
      };
      document.addEventListener("keydown", handleEscape);
      return () => document.removeEventListener("keydown", handleEscape);
    }, [id, isDismissible]);
    return /* @__PURE__ */ React__default.createElement(
      Element,
      {
        as: "dialog",
        id: modalId,
        "data-modal": true,
        popover: isDismissible ? "auto" : "manual",
        ref,
        classNames,
        role: "dialog",
        "aria-modal": "true",
        "aria-label": label || "Modal dialog",
        "aria-describedby": descriptionId,
        ...props
      },
      isDismissible && /* @__PURE__ */ React__default.createElement(
        Text,
        {
          className: "dismiss-button",
          onClick: () => hideModal(id),
          "aria-label": "Close modal",
          tabIndex: 0
        },
        "×"
      ),
      description && /* @__PURE__ */ React__default.createElement("div", { id: descriptionId, className: "sr-only" }, description),
      /* @__PURE__ */ React__default.createElement("div", { role: "document" }, children)
    );
  }
);
const showModal = (modalId) => {
  const modal = document.querySelector(`#modal-${modalId}[data-modal]`);
  if (modal instanceof HTMLElement) {
    modal.showPopover();
    const focusableElements = modal.querySelectorAll(
      'button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])'
    );
    if (focusableElements.length) {
      focusableElements[0].focus();
    }
  }
};
const hideModal = (modalId) => {
  const modal = document.querySelector(`#modal-${modalId}[data-modal]`);
  if (modal instanceof HTMLElement) {
    modal.hidePopover();
    if (document.activeElement instanceof HTMLElement) {
      document.activeElement.blur();
    }
  }
};
const toggleModal = (modalId) => {
  const modal = document.querySelector(`#modal-${modalId}[data-modal]`);
  if (modal instanceof HTMLElement) {
    modal.matches(":popover-open") ? hideModal(modalId) : showModal(modalId);
  }
};
export {
  Modal,
  hideModal,
  showModal,
  toggleModal
};
