"use client";
"use client;";
import React__default, { useState, useEffect } from "react";
import { Div } from "../../Element/Tags.js";
import { Element } from "../../Element/Element.js";
const NotificationItem = React__default.forwardRef(
  ({
    showWhen,
    closeWhen,
    kind = "info",
    children,
    isDismissible,
    secondsToShowFor,
    title,
    description,
    ...props
  }, ref) => {
    let classNames = [];
    const [isVisible, setIsVisible] = useState(showWhen);
    useEffect(() => {
      if (showWhen) {
        setIsVisible(true);
      }
      const timer = showWhen ? setTimeout(() => {
        closeWhen();
      }, (secondsToShowFor ?? 8) * 1e3) : void 0;
      return () => {
        timer && clearTimeout(timer);
      };
    }, [showWhen, secondsToShowFor, closeWhen]);
    if (kind) {
      classNames.push(kind);
    }
    if (isDismissible) {
      classNames.push("dismissible");
    }
    const onDismissClick = (event) => {
      event.preventDefault();
      closeWhen();
    };
    const handleKeyDown = (event) => {
      if (event.key === "Enter" || event.key === " ") {
        event.preventDefault();
        closeWhen();
      }
    };
    const onTransitionEnd = () => {
      if (!showWhen) setIsVisible(false);
    };
    const roleMap = {
      info: "status",
      warning: "alert",
      error: "alert",
      success: "status"
    };
    return isVisible && /* @__PURE__ */ React__default.createElement(
      Element,
      {
        as: "div",
        "data-notification-item": true,
        ref,
        classNames: [...classNames, !showWhen ? "dismissed" : ""],
        onTransitionEnd,
        role: roleMap[kind],
        "aria-live": kind === "error" || kind === "warning" ? "assertive" : "polite",
        "aria-atomic": "true",
        "aria-label": title,
        ...props
      },
      /* @__PURE__ */ React__default.createElement("div", { id: `notification-content-${props.id}` }, children, description && /* @__PURE__ */ React__default.createElement("span", { className: "sr-only" }, description)),
      isDismissible && /* @__PURE__ */ React__default.createElement(
        Div,
        {
          className: "dismiss-button",
          onClick: onDismissClick,
          onKeyDown: handleKeyDown,
          "aria-label": "Dismiss notification",
          tabIndex: 0
        },
        /* @__PURE__ */ React__default.createElement("span", { className: "sr-only" }, "Close notification")
      )
    );
  }
);
export {
  NotificationItem
};
