"use client";
"use client;";
import React__default, { createContext, useContext, useState, useCallback } from "react";
import { Element } from "../Element/Element.js";
import { Card } from "../Card/Card.js";
const OptionCardsContext = createContext({
  isSelected: () => false,
  toggleSelection: () => {
  },
  showTickIcon: false,
  tickPosition: "top-right"
});
const OptionCardsGroup = ({
  children,
  allowMultipleSelections = false,
  showTickIcon,
  onSelectionChange,
  tickPosition = "top-right",
  ...props
}) => {
  const [selectedIds, setSelectedIds] = useState(/* @__PURE__ */ new Set());
  const toggleSelection = useCallback((id) => {
    setSelectedIds((prevSelectedIds) => {
      const newSelectedIds = new Set(prevSelectedIds);
      if (allowMultipleSelections) {
        if (newSelectedIds.has(id)) {
          newSelectedIds.delete(id);
        } else {
          newSelectedIds.add(id);
        }
      } else {
        if (newSelectedIds.has(id) && prevSelectedIds.size === 1) {
          newSelectedIds.clear();
        } else {
          newSelectedIds.clear();
          newSelectedIds.add(id);
        }
      }
      onSelectionChange == null ? void 0 : onSelectionChange(newSelectedIds);
      return newSelectedIds;
    });
  }, [allowMultipleSelections, onSelectionChange]);
  const isSelected = useCallback((id) => {
    return selectedIds.has(id);
  }, [selectedIds]);
  return /* @__PURE__ */ React__default.createElement(OptionCardsContext.Provider, { value: { isSelected, toggleSelection, showTickIcon, tickPosition } }, /* @__PURE__ */ React__default.createElement("div", { "data-option-cards-group": true, className: `tick-${tickPosition}` }, children));
};
const useOptionCard = (id) => {
  const context = useContext(OptionCardsContext);
  return {
    isSelected: context.isSelected(id),
    toggleSelection: () => context.toggleSelection(id),
    showTickIcon: context.showTickIcon
  };
};
const OptionCard = ({ id, children, disabled = false, ...props }) => {
  const { isSelected, toggleSelection, showTickIcon } = useOptionCard(id);
  const [showDeselect, setShowDeselect] = useState(false);
  const [isInitialHover, setIsInitialHover] = useState(true);
  let classNames = [];
  if (isSelected) {
    classNames.push("selected");
  }
  if (disabled) {
    classNames.push("disabled");
  }
  if (showDeselect) {
    classNames.push("show-deselect");
  }
  const handleMouseEnter = () => {
    if (isSelected && !isInitialHover) {
      setShowDeselect(true);
    }
  };
  const handleMouseLeave = () => {
    setShowDeselect(false);
    setIsInitialHover(false);
  };
  const handleClick = (e) => {
    var _a;
    if (!disabled) {
      setIsInitialHover(true);
      setShowDeselect(false);
      toggleSelection();
      (_a = props.onClick) == null ? void 0 : _a.call(props, e);
    }
  };
  const handleKeyDown = (e) => {
    if ((e.key === "Enter" || e.key === " ") && !disabled) {
      e.preventDefault();
      setIsInitialHover(true);
      setShowDeselect(false);
      toggleSelection();
    }
  };
  return /* @__PURE__ */ React__default.createElement(
    Element,
    {
      as: Card,
      "data-option-card": true,
      role: "button",
      tabIndex: disabled ? -1 : 0,
      "aria-disabled": disabled ? "true" : "false",
      "aria-selected": isSelected ? "true" : "false",
      classNames,
      onClick: handleClick,
      onKeyDown: handleKeyDown,
      onMouseEnter: handleMouseEnter,
      onMouseLeave: handleMouseLeave,
      ...props
    },
    showTickIcon && /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24", className: "tick-icon" }, /* @__PURE__ */ React__default.createElement("circle", { cx: "12", cy: "12", r: "11" }), /* @__PURE__ */ React__default.createElement("path", { d: "M8 13 L11 15 L16 9" })), /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24", className: "deselect-icon" }, /* @__PURE__ */ React__default.createElement("circle", { cx: "12", cy: "12", r: "11" }), /* @__PURE__ */ React__default.createElement("path", { d: "M8 8 L16 16 M16 8 L8 16" }))),
    children
  );
};
export {
  OptionCard,
  OptionCardsGroup,
  useOptionCard
};
