"use client";
"use client;";
import React__default from "react";
import { Element } from "../Element/Element.js";
import { Div } from "../Element/Tags.js";
import { Text } from "../Typography/Text.js";
import { Spinner } from "../Spinner/Spinner.js";
import { Button } from "../Button/Button.js";
import { usePagination } from "./usePagination.js";
const defaultRenderItem = ({
  type,
  page,
  selected,
  disabled,
  onClick,
  key,
  ...props
}) => {
  if (type === "ellipsis") {
    return /* @__PURE__ */ React__default.createElement(Text, { className: "pagination-ellipsis" }, "...");
  }
  const paginationItemProps = {
    type: "button",
    className: `pagination-item ${selected ? "selected" : ""} ${disabled ? "disabled" : ""}`,
    onClick,
    disabled,
    ...props
  };
  let content;
  switch (type) {
    case "first":
      content = content = /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24" }, /* @__PURE__ */ React__default.createElement("line", { x1: "5", y1: "18", x2: "5", y2: "6" }), /* @__PURE__ */ React__default.createElement("polyline", { points: "14 18 9 12 14 6" }), /* @__PURE__ */ React__default.createElement("line", { x1: "10", y1: "12", x2: "19", y2: "12" }));
      break;
    case "previous":
      content = /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24" }, /* @__PURE__ */ React__default.createElement("polyline", { points: "12 18 7 12 12 6" }), /* @__PURE__ */ React__default.createElement("line", { x1: "8", y1: "12", x2: "17", y2: "12" }));
      break;
    case "next":
      content = content = /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24" }, /* @__PURE__ */ React__default.createElement("polyline", { points: "12 6 17 12 12 18" }), /* @__PURE__ */ React__default.createElement("line", { x1: "16", y1: "12", x2: "7", y2: "12" }));
      break;
    case "last":
      content = content = /* @__PURE__ */ React__default.createElement("svg", { viewBox: "0 0 24 24" }, /* @__PURE__ */ React__default.createElement("polyline", { points: "10 6 15 12 10 18" }), /* @__PURE__ */ React__default.createElement("line", { x1: "19", y1: "6", x2: "19", y2: "18" }), /* @__PURE__ */ React__default.createElement("line", { x1: "14", y1: "12", x2: "5", y2: "12" }));
      break;
    default:
      content = page;
  }
  return /* @__PURE__ */ React__default.createElement(
    Button,
    {
      kind: "custom",
      ...paginationItemProps
    },
    content
  );
};
const Pagination = React__default.forwardRef(
  ({
    totalItems,
    currentPage,
    onPageChange,
    itemsToShowEachSide = 1,
    kind = "plain",
    showGoToFirstItemButton = true,
    showGoToLastItemButton = true,
    showPreviousButton = true,
    showNextButton = true,
    showGoToInput = false,
    disabled = false,
    hideDisabledButtons = false,
    renderItem = defaultRenderItem,
    isLoading = false,
    loadingText,
    emptyText,
    itemDisplayText = "page",
    ...props
  }, ref) => {
    const {
      items,
      totalPages,
      rangeStart,
      rangeEnd,
      hasPrevPage,
      hasNextPage
    } = usePagination({
      totalItems,
      currentPage,
      itemsToShowEachSide
    });
    const [goToPage, setGoToPage] = React__default.useState("");
    const handlePageInputChange = (e) => {
      setGoToPage(e.target.value);
    };
    const handlePageInputKeyPress = (e) => {
      if (e.key === "Enter") {
        const page = parseInt(goToPage);
        if (!isNaN(page) && page >= 1 && page <= totalPages) {
          onPageChange(page);
          setGoToPage("");
        }
      }
    };
    if (totalItems === 0) {
      return /* @__PURE__ */ React__default.createElement(Text, { className: "pagination-empty" }, emptyText || "No items to display");
    }
    let classNames = ["pagination"];
    if (kind) {
      classNames.push(kind);
    }
    if (disabled) {
      classNames.push("disabled");
    }
    if (isLoading) {
      classNames.push("loading");
    }
    return /* @__PURE__ */ React__default.createElement(
      Element,
      {
        as: "nav",
        "data-pagination": true,
        ref,
        classNames,
        role: "navigation",
        "aria-label": "pagination",
        ...props
      },
      /* @__PURE__ */ React__default.createElement(Div, { className: "pagination-controls" }, showGoToFirstItemButton && (!hideDisabledButtons || hasPrevPage) && renderItem({
        type: "first",
        disabled: !hasPrevPage || disabled,
        selected: false,
        onClick: () => onPageChange(1)
      }), showPreviousButton && (!hideDisabledButtons || hasPrevPage) && renderItem({
        type: "previous",
        disabled: !hasPrevPage || disabled,
        selected: false,
        onClick: () => onPageChange(currentPage - 1)
      }), items.map((item, index) => {
        const itemProps = item === "..." ? {
          key: `ellipsis-${index}`,
          type: "ellipsis",
          selected: false,
          disabled: true
        } : {
          key: item.toString(),
          type: "page",
          page: item,
          selected: item === currentPage,
          disabled,
          "aria-current": item === currentPage ? "page" : void 0,
          onClick: () => onPageChange(item)
        };
        return renderItem(itemProps);
      }), showNextButton && (!hideDisabledButtons || hasNextPage) && renderItem({
        type: "next",
        disabled: !hasNextPage || disabled,
        selected: false,
        onClick: () => onPageChange(currentPage + 1)
      }), showGoToLastItemButton && (!hideDisabledButtons || hasNextPage) && renderItem({
        type: "last",
        disabled: !hasNextPage || disabled,
        selected: false,
        onClick: () => onPageChange(totalPages)
      }), isLoading && /* @__PURE__ */ React__default.createElement(Div, { className: "pagination-loading" }, /* @__PURE__ */ React__default.createElement(Spinner, null), loadingText && /* @__PURE__ */ React__default.createElement(Text, { size: "small" }, loadingText))),
      /* @__PURE__ */ React__default.createElement(Div, { className: "pagination-info" }, /* @__PURE__ */ React__default.createElement(Text, { size: "small" }, "Showing ", itemDisplayText, " ", rangeStart, " of ", totalItems), showGoToInput && /* @__PURE__ */ React__default.createElement(Div, { className: "pagination-go-to" }, /* @__PURE__ */ React__default.createElement(
        "input",
        {
          type: "number",
          min: 1,
          max: totalPages,
          value: goToPage,
          onChange: handlePageInputChange,
          onKeyDown: handlePageInputKeyPress,
          placeholder: `Go to ${itemDisplayText}`,
          "aria-label": `Go to ${itemDisplayText}`,
          disabled
        }
      )))
    );
  }
);
export {
  Pagination
};
