"use client";
"use client;";
import React__default, { createContext, useContext } from "react";
import { Element } from "../Element/Element.js";
const SkeletonContext = createContext({
  effect: "wave",
  animate: true
});
const Skeleton = React__default.forwardRef(({
  variant = "line",
  width,
  height,
  shape,
  effect: localEffect,
  loadingLabel,
  ...props
}, ref) => {
  const groupContext = useContext(SkeletonContext);
  const effectiveEffect = localEffect || groupContext.effect;
  const effectiveLabel = loadingLabel || groupContext.loadingLabel || "Loading...";
  let classNames = [];
  if (variant) {
    classNames.push(`variant-${variant}`);
  }
  if (shape) {
    classNames.push(`shape-${shape}`);
  }
  if (effectiveEffect) {
    classNames.push(`effect-${effectiveEffect}`);
  }
  const computedWidth = width || "100%";
  const computedHeight = variant === "circle" ? (typeof width === "number" ? `${width}px` : width) || height || "100%" : height;
  const style = {
    width: computedWidth,
    height: computedHeight,
    aspectRatio: variant === "circle" ? "1 / 1" : "auto",
    ...props.style
  };
  return /* @__PURE__ */ React__default.createElement(
    Element,
    {
      as: "div",
      "data-skeleton": true,
      ref,
      classNames,
      style,
      role: "progressbar",
      "aria-busy": "true",
      "aria-valuemin": 0,
      "aria-valuemax": 100,
      "aria-valuetext": effectiveLabel,
      "aria-label": effectiveLabel,
      ...props
    }
  );
});
const SkeletonGroup = React__default.forwardRef(({
  effect = "wave",
  spacing = "small",
  animate = true,
  repeat = 1,
  direction = "vertical",
  children,
  classNames = [],
  loadingLabel = "Loading content...",
  ...props
}, ref) => {
  const groupClassNames = [
    `direction-${direction}`,
    effect && `effect-${effect}`,
    ...classNames
  ];
  if (spacing) {
    groupClassNames.push(`spacing-${spacing}`);
  }
  return /* @__PURE__ */ React__default.createElement(SkeletonContext.Provider, { value: { effect, animate, loadingLabel } }, /* @__PURE__ */ React__default.createElement(
    Element,
    {
      as: "div",
      ref,
      "data-skeleton-group": true,
      classNames: groupClassNames,
      role: "alert",
      "aria-busy": "true",
      "aria-label": loadingLabel,
      ...props
    },
    Array(repeat).fill(children).map((child, index) => React__default.cloneElement(child, {
      key: index
    }))
  ));
});
export {
  Skeleton,
  SkeletonGroup
};
